---@type LazySpec
return {
  "nvimtools/none-ls.nvim",
  lazy = false,
    opts = function(_, config)
      local null_ls = require("null-ls")

      local leptosfmt = {
        name = "leptosfmt",
        meta = {
          url = "https://github.com/bram209/leptosfmt",
          description = "A formatter for the leptos view! macro.",
        },
        method = null_ls.methods.FORMATTING,
        filetypes = { "rust" },
        condition = function(utils)
          return utils.root_has_file("leptosfmt.toml")
        end,
        generator = null_ls.formatter({
          command = "leptosfmt",
          args = { "--stdin", "--quiet" },
          to_stdin = true,
          from_stderr = false,
          from_stdout = true,
        }),
      }

      config.sources = {
        null_ls.builtins.formatting.shfmt.with({
          filetypes = { "sh", "bash", "zsh", "pkgbuild" },
        }),
        null_ls.builtins.formatting.sql_formatter.with({
          extra_args = { "--config", vim.env.XDG_CONFIG_HOME .. "/sql-formatter.json" },
        }),
        null_ls.builtins.formatting.prettier.with({
          filetypes = { "json", "markdown", "yaml", "html", "css" },
        }),
        leptosfmt,
      }

      return config
    end
}
